==> apache-dubbo-2.7.2-src.zip: apache-dubbo-2.7.2-src/dubbo-config/dubbo-config-api/src/test/java/org/apache/dubbo/config/utils/MockReferenceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.config.utils;

import org.apache.dubbo.config.ReferenceConfig;

import java.util.concurrent.atomic.AtomicLong;

public class MockReferenceConfig extends ReferenceConfig<String> {
    static AtomicLong counter = new AtomicLong();

    String value;
    boolean destroyMethodRun = false;

    public static void setCounter(long c) {
        counter.set(c);
    }

    public boolean isGetMethodRun() {
        return value != null;
    }

    public boolean isDestroyMethodRun() {
        return destroyMethodRun;
    }

    @Override
    public synchronized String get() {
        if (value != null) return value;

        value = "" + counter.getAndIncrement();
        return value;
    }

    @Override
    public synchronized void destroy() {
        destroyMethodRun = true;
    }
}

==> apache-dubbo-2.7.18-src.zip: apache-dubbo-2.7.18-src/dubbo-config/dubbo-config-api/src/test/java/org/apache/dubbo/config/utils/MockReferenceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.config.utils;

import org.apache.dubbo.config.ReferenceConfig;
import org.apache.dubbo.config.utils.service.FooService;

import java.util.concurrent.atomic.AtomicLong;

public class MockReferenceConfig extends ReferenceConfig<FooService> {
    static AtomicLong counter = new AtomicLong();

    FooService value;
    boolean destroyMethodRun = false;

    public static void setCounter(long c) {
        counter.set(c);
    }

    public boolean isGetMethodRun() {
        return value != null;
    }

    public boolean isDestroyMethodRun() {
        return destroyMethodRun;
    }

    @Override
    public synchronized FooService get() {
        if (value != null) return value;

        counter.getAndIncrement();
        value = super.get();
        return value;
    }

    public long getCounter() {
        return counter.get();
    }

    @Override
    public synchronized void destroy() {
        destroyMethodRun = true;
    }
}
